phoneuis/dialer/inc/cdialernumberentry.h
branchRCL_3
changeset 3 8871b09be73b
parent 0 5f000ab63145
child 6 38529f706030
--- a/phoneuis/dialer/inc/cdialernumberentry.h	Tue Feb 02 00:10:04 2010 +0200
+++ b/phoneuis/dialer/inc/cdialernumberentry.h	Fri Feb 19 22:50:26 2010 +0200
@@ -28,6 +28,7 @@
 #include <AknPhoneNumberEditor.h>
 
 #include "cdialercontainerbase.h"
+#include "dialer.hrh"
 
 // CONSTANTS
 
@@ -37,7 +38,7 @@
 class CAknsFrameBackgroundControlContext;
 class MNumberEntryObserver;
 class CEikLabel;
-
+class CDialingExtensionInterface;
 
 // Number entry varietys
 enum TDialerNEVariety
@@ -111,10 +112,16 @@
         void SetTextToNumberEntry( const TDesC& aDesC );
 
         /**
+        * Returns TPtrC pointed to editor text.
+        * @return   Pointer to editor text.
+        */
+        TPtrC Text() const;
+        
+        /**
         * Get tect from number entry.
         * @param aDesc Text is returned here.
         */
-        void GetTextFromNumberEntry( TDes& aDesC );
+        void GetTextFromNumberEntry( TDes& aDes );
 
         /**
         * Reset editor to default values.
@@ -143,7 +150,13 @@
         * Clear editor flags to default values.
         */
         void ClearEditorFlags();
+
+        void SetEasyDialingPlugin( CDialingExtensionInterface* iEasyDialer );
         
+        void SetOperationMode( TDialerOperationMode aMode );
+        
+        TBool Validate( const TDesC& aString );
+
     private:  // Functions from MCoeControlObserver
         /**
         * @see MCoeControlObserver
@@ -178,12 +191,22 @@
         */
         void HandleResourceChange( TInt aType );        
 
+        /**
+        * @see CCoeControl
+        */
+        void HandlePointerEventL( const TPointerEvent& aPointerEvent );
+
     public:        
         /**
         * @see CCoeControl
         */
         void SetFocus( TBool aFocus, 
                        TDrawNow aDrawNow=ENoDrawNow );
+					   
+		/**
+        * @see CCoeControl
+        */			   
+        void MakeVisible( TBool aVisible );
    
     private: // From CDialerContainerBase
 
@@ -289,6 +312,16 @@
         MNumberEntryObserver* iObserver;    
         
         TBool iNumberContents;  
+        
+        TBuf<KDialerPhoneNumberEntryBufferSize> iPreviousNumberEntryContent;
+
+        // NOT OWN
+        CDialingExtensionInterface* iEasyDialer;
+        
+        TDialerOperationMode iOperationMode;
+        
+        // NOT OWNED.
+        CEikAppUi* iAppUi;
     };
 
 #endif      // CDIALERNUMBERENTRY_H
@@ -111,10 +112,16 @@
         * Get tect from number entry.
-        * @param aDesc Text is returned here.
+        * @param aDes Text is returned here.
         */